@@ -712,7 +712,7 @@ set of useful URLs or preparing a list to send to a someone else."
   "Render a menu for a given mode symbol."
   (spinneret:with-html
     (:div :class "mode-menu"
-          (loop for command in (nyxt::list-mode-commands mode-symbol)
+          (loop for command in (list-mode-commands mode-symbol)
                 collect
                    (let ((name (string-downcase (closer-mop:generic-function-name command)))
                          (bindings (keymaps:pretty-binding-keys
