@@ -25,6 +25,18 @@
     (loop for version being the hash-value of +changelog+
           collect (:raw version))))
 
+(define-version "3.11.7"
+  (:nsection :title "Bug fixes"
+    (:ul
+     (:li "Fix query handling when invoking command" (:nxref :command 'set-url) ".")
+     (:li "Fix incorrect redirection when "
+          (:nxref :class-name 'nyxt/mode/reduce-tracking:reduce-tracking-mode)
+          " is enabled.")
+     (:li "Improve clipboard facilities detection on X11 and Wayland."))
+    (:nsection :title "UI/UX"
+      (:ul
+       (:li "Bind common zoom keybindings for all keyschemes.")))))
+
 (define-version "3.11.6"
   (:nsection :title "Bug fixes"
     (:ul
